==> kubernetes-annotations-2.6.0-sources.jar: io/dekorate/kubernetes/config/RollingUpdateFluentImpl.java <==
package io.dekorate.kubernetes.config;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
public class RollingUpdateFluentImpl<A extends io.dekorate.kubernetes.config.RollingUpdateFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.dekorate.kubernetes.config.RollingUpdateFluent<A>{
  public RollingUpdateFluentImpl() {
  }
  public RollingUpdateFluentImpl(io.dekorate.kubernetes.config.RollingUpdate instance) {
    this.withMaxUnavailable(instance.getMaxUnavailable()); 
    this.withMaxSurge(instance.getMaxSurge()); 
  }
  private java.lang.String maxUnavailable;
  private java.lang.String maxSurge;
  public java.lang.String getMaxUnavailable() {
    return this.maxUnavailable;
  }
  public A withMaxUnavailable(java.lang.String maxUnavailable) {
    this.maxUnavailable=maxUnavailable; return (A) this;
  }
  public java.lang.Boolean hasMaxUnavailable() {
    return this.maxUnavailable != null;
  }
  
  /**
   * Method is deprecated. use withMaxUnavailable instead.
   */
  @java.lang.Deprecated
  public A withNewMaxUnavailable(java.lang.String arg0) {
    return (A)withMaxUnavailable(new String(arg0));
  }
  public java.lang.String getMaxSurge() {
    return this.maxSurge;
  }
  public A withMaxSurge(java.lang.String maxSurge) {
    this.maxSurge=maxSurge; return (A) this;
  }
  public java.lang.Boolean hasMaxSurge() {
    return this.maxSurge != null;
  }
  
  /**
   * Method is deprecated. use withMaxSurge instead.
   */
  @java.lang.Deprecated
  public A withNewMaxSurge(java.lang.String arg0) {
    return (A)withMaxSurge(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RollingUpdateFluentImpl that = (RollingUpdateFluentImpl) o;
    if (maxUnavailable != null ? !maxUnavailable.equals(that.maxUnavailable) :that.maxUnavailable != null) return false;
    if (maxSurge != null ? !maxSurge.equals(that.maxSurge) :that.maxSurge != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(maxUnavailable,  maxSurge,  super.hashCode());
  }
  
}

==> kubernetes-annotations-2.11.3-sources.jar: io/dekorate/kubernetes/config/RollingUpdateFluentImpl.java <==
package io.dekorate.kubernetes.config;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RollingUpdateFluentImpl<A extends RollingUpdateFluent<A>> extends BaseFluent<A> implements RollingUpdateFluent<A>{
  public RollingUpdateFluentImpl() {
  }
  public RollingUpdateFluentImpl(io.dekorate.kubernetes.config.RollingUpdate instance) {
    this.withMaxUnavailable(instance.getMaxUnavailable()); 
    this.withMaxSurge(instance.getMaxSurge()); 
  }
  private String maxUnavailable;
  private java.lang.String maxSurge;
  public java.lang.String getMaxUnavailable() {
    return this.maxUnavailable;
  }
  public A withMaxUnavailable(java.lang.String maxUnavailable) {
    this.maxUnavailable=maxUnavailable; return (A) this;
  }
  public Boolean hasMaxUnavailable() {
    return this.maxUnavailable != null;
  }
  public java.lang.String getMaxSurge() {
    return this.maxSurge;
  }
  public A withMaxSurge(java.lang.String maxSurge) {
    this.maxSurge=maxSurge; return (A) this;
  }
  public java.lang.Boolean hasMaxSurge() {
    return this.maxSurge != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RollingUpdateFluentImpl that = (RollingUpdateFluentImpl) o;
    if (maxUnavailable != null ? !maxUnavailable.equals(that.maxUnavailable) :that.maxUnavailable != null) return false;
    if (maxSurge != null ? !maxSurge.equals(that.maxSurge) :that.maxSurge != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(maxUnavailable,  maxSurge,  super.hashCode());
  }
  public java.lang.String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (maxUnavailable != null) { sb.append("maxUnavailable:"); sb.append(maxUnavailable + ","); }
    if (maxSurge != null) { sb.append("maxSurge:"); sb.append(maxSurge); }
    sb.append("}");
    return sb.toString();
  }
  
}
